@@ -87,7 +87,7 @@ static void e_webcal_icon_theme_changed (GnomeIconTheme * theme,
 					 EIcalShareDialog * dialog) {
   gchar * icofile;
 
-  icofile = gnome_icon_theme_lookup_icon (dialog->theme, "stock_web-calendar",
+  icofile = gnome_icon_theme_lookup_icon (dialog->theme, "x-office-calendar",
 					  48, NULL, NULL);
 
   if (icofile != NULL) {
@@ -361,7 +361,7 @@ void e_webcal_query_user (const gchar * name, const gchar * desc,
   gtk_window_set_default_size (GTK_WINDOW (dialog->dialog), 376, 144);
 
   icofile = gnome_icon_theme_lookup_icon (dialog->theme,
-					  "stock_web-calendar",
+					  "x-office-calendar",
 					  48, NULL, NULL);
   if (icofile != NULL) {
     gtk_window_set_default_icon_from_file (icofile, NULL);
